@@ -65,7 +65,7 @@ class ConfigurationBase():
             parser.add_argument('action', help='Action to be performed', choices=kAction)    
         elif action == 'list':
             parser.add_argument('--expr', metavar='',
-            	help='Filter out config files that matches the expression')
+                help='Filter out config files that matches the expression')
         elif action == 'show':
             parser.add_argument('name', help='Name of config file to show')
         elif action == 'remove':
@@ -103,6 +103,8 @@ class ConfigurationBase():
         if os.path.exists(config_path):
             os.remove(config_path)
             print('INFO: Removed file {}'.format(config_path))
+        else:
+            print('ERROR: Cannot remove file {}. File does not exist.'.format(config_path))
 
     def get_updated_config(self, config):
         non_updated_keys = []
@@ -150,7 +152,8 @@ class ConfigurationBase():
                 'If you want to overwrite, use "recreate" or "update" action instead of "create".'.format(
                 self.config_type, name))
         else:
-            json.dump(config, open(config_path,'w'))
+            with open(config_path, 'w') as config_file:
+                json.dump(config, config_file, indent=2)
             action_map = { 'create': 'Created', 'recreate': 'Recreated', 'update': 'Updated'}
             print('INFO: {} {} configuration {}'.format(action_map[action], self.config_type, config_path))
             self.show(name)
@@ -195,33 +198,33 @@ class HPOConfiguration(ConfigurationBase):
         if action in kConfigAction:
             parser.add_argument('name', help= "Name given to the configuration file")
             parser.add_argument('-a','--algorithm', 
-            					help='Algorithm for hyperparameter optimization', 
+                                help='Algorithm for hyperparameter optimization', 
                                 default=kDefaultSearchAlgorithm, choices=kSearchAlgorithms)
             parser.add_argument('-m', '--metric', metavar='',
-            					help='Evaluation metric to be optimized', 
+                                help='Evaluation metric to be optimized', 
                                 default=kDefaultMetric)
             parser.add_argument('-o', '--mode', 
-            					help='Mode of optimization (either "min" or "max")', 
+                                help='Mode of optimization (either "min" or "max")', 
                                 default=kDefaultMode, choices=kMetricMode)
             parser.add_argument('-s','--scheduler', 
-            					help='Trial scheduling method for hyperparameter optimization',
+                                help='Trial scheduling method for hyperparameter optimization',
                                 default=kDefaultScheduler, choices=kSchedulers)
             parser.add_argument('-t','--trials', metavar='',
-            					help='Number of trials (search points)', 
-            					type=int, default=kDefaultTrials)
+                                help='Number of trials (search points)', 
+                                type=int, default=kDefaultTrials)
             parser.add_argument('-l', '--log_dir', metavar='',
-            					help='Logging directory',
+                                help='Logging directory',
                                 default=kDefaultLogDir)
             parser.add_argument('-v','--verbose', action='store_true', 
-            					help='Check to enable verbosity')
+                                help='Check to enable verbosity')
             parser.add_argument('--stop', metavar='',
-            					help='Stopping criteria for the training',
+                                help='Stopping criteria for the training',
                                 default=kDefaultStopping)
             parser.add_argument('--scheduler_param', metavar='',
-            					help='Extra parameters given to the trial scheduler', 
+                                help='Extra parameters given to the trial scheduler', 
                                 default=kDefaultSchedulerParam)
             parser.add_argument('--algorithm_param', metavar='',
-            					help='Extra parameters given to the hyperparameter optimization algorithm',
+                                help='Extra parameters given to the hyperparameter optimization algorithm',
                                 default=kDefaultAlgorithmParam)
         else:
             parser = super().get_parser(action)
@@ -256,20 +259,20 @@ class GridConfiguration(ConfigurationBase):
         if action in kConfigAction:         
             parser.add_argument('name', help = "Name given to the configuration file")
             parser.add_argument('-s', '--site', 
-            					help='Name of the grid site to where the jobs are submitted',
+                                help='Name of the grid site to where the jobs are submitted',
                                 required=False, default=kDefaultGridSite,
                                 choices=kGPUGridSiteList)
             parser.add_argument('-c', '--container', metavar='',
-            					help='Name of the docker or singularity container in which the jobs are run', 
+                                help='Name of the docker or singularity container in which the jobs are run', 
                                 required=False, default=kDefaultContainer)
-            parser.add_argument('-r', '--retry', metavar='',
-            					helper='Check to enable retrying faild jobs',
-            					action='store_true')
+            parser.add_argument('-r', '--retry',
+                                help='Check to enable retrying faild jobs',
+                                action='store_true')
             parser.add_argument('-i', '--inDS', metavar='',
-            					help='Name of input dataset')
+                                help='Name of input dataset')
             parser.add_argument('-o', '--outDS', metavar='',
-            					help='Name of output dataset', 
-            					default=kDefaultOutDS)                                                                        
+                                help='Name of output dataset', 
+                                default=kDefaultOutDS)                                                                        
         else:
             parser = super().get_parser(action)
         return parser
@@ -289,9 +292,9 @@ class SearchSpaceConfiguration(ConfigurationBase):
         parser = self.get_base_parser()               
         if action in kConfigAction:     
             parser.add_argument('name', 
-            	help='Name given to the configuration file')  
+                help='Name given to the configuration file')  
             parser.add_argument('search_space', 
-            	help='A json decodable string defining the search space')  
+                help='A json decodable string defining the search space')  
         else:
             parser = super().get_parser(action)
         return parser
@@ -333,13 +336,13 @@ class ModelConfiguration(ConfigurationBase):
         if action in kConfigAction:  
             parser.add_argument('name', help= "Name given to the configuration file")            
             parser.add_argument('-s','--script', metavar='',
-            	help='Name of the training script where the function or class that defines'
-            		 ' the training model will be called to perform the training')
+                help='Name of the training script where the function or class that defines'
+                     ' the training model will be called to perform the training')
             parser.add_argument('-m','--model', metavar='',
-            	help='Name of the function or class that defines the training model')        
+                help='Name of the function or class that defines the training model')        
             parser.add_argument('-p','--param', metavar='',
-            	help='Extra parameters to be passed to the training model',
-            	default=kDefaultModelParam)
+                help='Extra parameters to be passed to the training model',
+                default=kDefaultModelParam)
         else:
             parser = super().get_parser(action)
         return parser
@@ -372,16 +375,16 @@ class ProjectConfiguration(ConfigurationBase):
         if action in kConfigAction:          
             parser.add_argument('name', help= "Name given the project")
             parser.add_argument('-p','--scripts_path', metavar='',
-            	help='Path to where the training scripts'
-            	' (or the directory containing the training scripts) are located')
+                help='Path to where the training scripts'
+                ' (or the directory containing the training scripts) are located')
             parser.add_argument('-o','--hpo_config', metavar='',
-            	help='Name of the hpo configuration to use')
+                help='Name of the hpo configuration to use')
             parser.add_argument('-g','--grid_config', metavar='',
-            	help='Name of the grid configuration to use')
+                help='Name of the grid configuration to use')
             parser.add_argument('-m','--model_config', metavar='',
-            	help='Name of the model configuration to use')
+                help='Name of the model configuration to use')
             parser.add_argument('-s','--search_space', metavar='',
-            	help='Name of the search space configuration to use')
+                help='Name of the search space configuration to use')
         else:
             parser = super().get_parser(action)
         return parser
@@ -426,10 +429,13 @@ class ProjectConfiguration(ConfigurationBase):
 
         return config
 
+    def get_project_path(self, proj_name):
+        return self.get_config_path(proj_name, self.config_type, extension='')
+
     def save(self, config, name, action='create'):
         proj_name = name
-        proj_dir = self.get_config_path(proj_name, self.config_type, extension='')
-        if (os.path.exists(proj_dir)):
+        proj_path = self.get_project_path(proj_name)
+        if (os.path.exists(proj_path)):
             if  action == 'create':
                 print('ERROR: Project titled {} already exists. If you want to overwrite,'
                     ' use "recreate" or "update" action instead of "create".'.format(proj_name))
@@ -439,13 +445,13 @@ class ProjectConfiguration(ConfigurationBase):
                 os.makedirs(backup_dir, exist_ok=True)
                 timestamp = datetime.now().strftime("%Y%m%d%H%M%S")
                 backup_proj_name = os.path.join(backup_dir, '{}_{}'.format(proj_name, timestamp))
-                shutil.move(proj_dir, backup_proj_name)
+                shutil.move(proj_path, backup_proj_name)
                 print('INFO: Recreating project. Original project moved to backup directory {}.'.format(
                     backup_proj_name))
         # create project directories
-        scripts_dir = os.path.join(proj_dir, 'scripts')
-        config_dir = os.path.join(proj_dir, 'config')
-        os.makedirs(proj_dir, exist_ok=True)        
+        scripts_dir = os.path.join(proj_path, 'scripts')
+        config_dir = os.path.join(proj_path, 'config')
+        os.makedirs(proj_path, exist_ok=True)        
         os.makedirs(scripts_dir, exist_ok=True)
         os.makedirs(config_dir, exist_ok=True)
 
@@ -466,13 +472,33 @@ class ProjectConfiguration(ConfigurationBase):
                 print('INFO: Copied {} to {}'.format(config[key], dest))
 
         project_config = {}
-        project_config_path = os.path.join(config_dir, 'project_config.json')
+        project_config_path = os.path.join(config_dir, kProjectConfigName)
         if os.path.exists(project_config_path):
             project_config = json.load(open(project_config_path))
         
         project_config = {**self.project_config, **project_config}
-        json.dump(project_config, open(project_config_path,'w'))
+        with open(project_config_path,'w') as proj_config_file:
+            json.dump(project_config, proj_config_file, indent=2)
 
     def get_config_list(self, expr=None):
         project_list = [ s for s in super().get_config_list() if s is not 'backup']
-        return project_list
\ No newline at end of file
+        return project_list
+
+    def remove(self, name):
+        proj_path = self.get_project_path(name)
+        if os.path.exists(proj_path):
+            print('WARNING: To avoid accidental deletion of important files. '
+                'Please delete your project manually at:\n{}'.format(proj_path))
+        else:
+            print('ERROR: Cannot remove project in {}. Path does not exist.'.format(proj_path))
+
+    def show(self, name):
+        proj_path = self.get_project_path(name)
+        config_path = os.path.join(proj_path, 'config', kProjectConfigName)
+        if os.path.exists(config_path):
+            with open(config_path,'r') as config_file:
+                config = json.load(config_file)
+            table = stylus.create_table(config.items(), self.show_columns)
+            print(table)
+        else:
+            print('ERROR: Project {} does not exist.'.format(name))
\ No newline at end of file
