@@ -99,6 +99,6 @@ def get_n_gpu():
 	physical_devices = get_physical_devices('GPU')
 	return len(physical_devices)
 
-def get_n_cpi():
+def get_n_cpu():
 	physical_devices = get_physical_devices('CPU')
 	return len(physical_devices)
\ No newline at end of file
